        function getT(rr,cc){
       if(rr==7 && cc==0){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==7 && cc==1){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==7 && cc==2){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==7 && cc==3){return '<strong>Temperatura (C) y Altura Geopotencial (m) en 500 hPa</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==34 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==34 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==34 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==34 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 1.25 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==35 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==35 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==35 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==35 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 2.5 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==36 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==36 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==36 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==36 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 4 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==37 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==37 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==37 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==37 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 6 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==38 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==38 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==38 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==38 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 9 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
       if(rr==39 && cc==0){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br><strong>control +<br>EPS</strong>';}
       if(rr==39 && cc==1){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>1</strong> representante: <strong>11</strong> miembros: 19 <br>4,5,11,13,14,15,16,19,21,22,25,27,30,31,32,41,43,44,48';}
       if(rr==39 && cc==2){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>2</strong> representante: <strong>9</strong> miembros: 19 <br>1,6,7,9,10,12,17,20,24,28,29,34,36,37,39,40,42,45,47';}
       if(rr==39 && cc==3){return '<strong>Probabilidad de altura significativa de olas de mar combinada superior a 14 m</strong><br><br><strong>20260810 a 00</strong> UTC HH+054 (rango:048-060)<br>grupo: <strong>3</strong> representante: <strong>3</strong> miembros: 13 <strong>control</strong><br>0,2,3,8,18,23,26,33,35,38,46,49,50';}
}
